@@ -8,7 +8,6 @@ scripts/create_escalation_exclusion.py - Easy way to routinely add particular
                                          days to the list of days on which no
                                          escalation should take place.
 """
-from __future__ import print_function
 
 from datetime import timedelta, date
 import getopt
@@ -16,12 +15,12 @@ from optparse import make_option
 import sys
 
 from django.core.management.base import BaseCommand, CommandError
+from django.db.models import Q
 
 from helpdesk.models import EscalationExclusion, Queue
 
 
 class Command(BaseCommand):
-
     def __init__(self):
         BaseCommand.__init__(self)
 
@@ -41,14 +40,12 @@ class Command(BaseCommand):
                 '--escalate-verbosely', '-x',
                 action='store_true',
                 default=False,
-                dest='escalate-verbosely',
                 help='Display a list of dates excluded'),
-        )
+            )
 
     def handle(self, *args, **options):
         days = options['days']
-        # optparse should already handle the `or 1`
-        occurrences = options['occurrences'] or 1
+        occurrences = options['occurrences']
         verbose = False
         queue_slugs = options['queues']
         queues = []
@@ -56,6 +53,8 @@ class Command(BaseCommand):
         if options['escalate-verbosely']:
             verbose = True
 
+        # this should already be handled by optparse
+        if not occurrences: occurrences = 1
         if not (days and occurrences):
             raise CommandError('One or more occurrences must be specified.')
 
@@ -96,23 +95,23 @@ def create_exclusions(days, occurrences, verbose, queues):
                     esc.save()
 
                     if verbose:
-                        print("Created exclusion for %s %s" % (day_name, workdate))
+                        print "Created exclusion for %s %s" % (day_name, workdate)
 
                     for q in queues:
                         esc.queues.add(q)
                         if verbose:
-                            print("  - for queue %s" % q)
+                            print "  - for queue %s" % q
 
                 i += 1
             workdate += timedelta(days=1)
 
 
 def usage():
-    print("Options:")
-    print(" --days, -d: Days of week (monday, tuesday, etc)")
-    print(" --occurrences, -o: Occurrences: How many weeks ahead to exclude this day")
-    print(" --queues, -q: Queues to include (default: all). Use queue slugs")
-    print(" --verbose, -v: Display a list of dates excluded")
+    print "Options:"
+    print " --days, -d: Days of week (monday, tuesday, etc)"
+    print " --occurrences, -o: Occurrences: How many weeks ahead to exclude this day"
+    print " --queues, -q: Queues to include (default: all). Use queue slugs"
+    print " --verbose, -v: Display a list of dates excluded"
 
 
 if __name__ == '__main__':
@@ -124,7 +123,7 @@ if __name__ == '__main__':
         sys.exit(2)
 
     days = None
-    occurrences = 1
+    occurrences = None
     verbose = False
     queue_slugs = None
     queues = []
@@ -137,8 +136,9 @@ if __name__ == '__main__':
         if o in ('-q', '--queues'):
             queue_slugs = a
         if o in ('-o', '--occurrences'):
-            occurrences = int(a) or 1
+            occurrences = int(a)
 
+    if not occurrences: occurrences = 1
     if not (days and occurrences):
         usage()
         sys.exit(2)
@@ -149,7 +149,7 @@ if __name__ == '__main__':
             try:
                 q = Queue.objects.get(slug__exact=queue)
             except Queue.DoesNotExist:
-                print("Queue %s does not exist." % queue)
+                print "Queue %s does not exist." % queue
                 sys.exit(2)
             queues.append(q)
 
