@@ -1,27 +1,30 @@
 """
 django-helpdesk - A Django powered ticket tracker for small enterprise.
 
-templatetags/saved_queries.py - This template tag returns previously saved
+templatetags/saved_queries.py - This template tag returns previously saved 
                                 queries. Therefore you don't need to modify
                                 any views.
 """
-from __future__ import print_function
+import sys
+
 from django.template import Library
 from django.db.models import Q
 from helpdesk.models import SavedSearch
 
+import six
 
-def saved_queries(user):
+def saved_queries(request):
     try:
-        user_saved_queries = SavedSearch.objects.filter(Q(user=user) | Q(shared__exact=True))
+        if not request.user.is_authenticated():
+            return ''
+        user_saved_queries = SavedSearch.objects.filter(Q(user=request.user) | Q(shared__exact=True))
         return user_saved_queries
     except Exception as e:
-        import sys
-        print("'saved_queries' template tag (django-helpdesk) crashed with following error:",
-              file=sys.stderr)
-        print(e, file=sys.stderr)
+        six.print_(
+            "Error in 'saved_queries' template tag (django-helpdesk):",
+            file=sys.stderr)
+        six.print_(e, file=sys.stderr)
         return ''
 
-
 register = Library()
 register.filter('saved_queries', saved_queries)
